# pybiouml

[BioUML](https://www.biouml.org/) - an integrated environment
for systems biology and collaborative analysis of biomedical data.
This library is a python interface which gives an opportunity to use BioUML 
through python scripts.
 
## Documentation

Documentation and use cases for pybiouml are presented available here:   
[Documentation and use cases](https://pybiouml.readthedocs.io/en/latest/source/api/pybiouml.html) 

## Instalation
For library instalation you can use the package 
manager [pip](https://pypi.org/project/pybiouml/).

```bash
pip install pybiouml 
```

## License
[MIT](https://choosealicense.com/licenses/mit/)